pub struct Image<'a> { /* private fields */ }Expand description
A JPEG2000 image or codestream.
Implementations
Sourceimpl<'a> Image<'a>
impl<'a> Image<'a>
Sourcepub fn new(data: &'a [u8], settings: &DecodeSettings) -> Result<Self>
pub fn new(data: &'a [u8], settings: &DecodeSettings) -> Result<Self>
Try to create a new JPEG2000 image from the given data.
Sourcepub fn color_space(&self) -> &ColorSpace
pub fn color_space(&self) -> &ColorSpace
The color space of the image.
Sourcepub fn original_bit_depth(&self) -> u8
pub fn original_bit_depth(&self) -> u8
The original bit depth of the image. You usually don’t need to do anything with this parameter, it just exists for informational purposes.
Sourcepub fn decode(&self) -> Result<Vec<u8>>
pub fn decode(&self) -> Result<Vec<u8>>
Decode the image and return its decoded result as a Vec<u8>, with each
channel interleaved.
Sourcepub fn decode_into(
&'a self,
buf: &mut [u8],
decoder_context: &mut DecoderContext<'a>,
) -> Result<()>
pub fn decode_into( &'a self, buf: &mut [u8], decoder_context: &mut DecoderContext<'a>, ) -> Result<()>
Decode the image into the given buffer.
This method does the same as Image::decode, but you can provide
a custom buffer for the output, as well as a decoder context. Doing
so will allow hayro-jpeg2000 to reuse memory allocations, so this is
especially recommended if you plan on converting multiple images
in the same session.
The buffer must have the correct size.